Coverage for test_rds.py: 0%

# Coverage for test_rds.py : 0%

## 7 statements 0 run 7 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 | # -*- coding: utf-8 -*- from jungle import cli def test_rds_ls(runner, rds): """jungle rds ls test""" result = runner.invoke(cli.cli, ['rds', 'ls']) assert result.exit_code == 0 def test_rds_ls_with_l(runner, rds): result = runner.invoke(cli.cli, ['rds', 'ls', '-l']) assert result.exit_code == 0